import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_codebuild._jsii
import aws_cdk.aws_codecommit._jsii
import aws_cdk.aws_codedeploy._jsii
import aws_cdk.aws_codepipeline._jsii
import aws_cdk.aws_codestarnotifications._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_lambda_event_sources._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.core._jsii
import cloudcomponents.cdk_chatops._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-developer-tools-notifications",
    "1.0.25",
    __name__[0:-6],
    "cdk-developer-tools-notifications@1.0.25.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
